==> sale-3.5.1.jar: revenue/sqls/revenue/BizOperation/WeChatciliation/WeChatPaydetail.sql <==
select  tt.*
from (
		SELECT  (CASE
                     WHEN s.f_serial_id IS NULL AND w.f_transaction_id IS NOT NULL THEN '微信单方面账单'
                     WHEN s.f_serial_id IS NOT NULL AND w.f_transaction_id IS NULL THEN '燃气方单方面账单'
                     else '对账成功'
				END) msg,
		        {entity.findDialect()==$SqlServer$: $isnull$,$NVL$}(( w.f_total_fee + 0.00 ) / ( 100 + 0.00 ),0) f_total_fee,
                w.f_attach,
                w.id,
                w.f_order_state,
                w.f_order_type,
                w.f_trade_type,
                {entity.findDialect()==$SqlServer$: $isnull$,$NVL$}(w.f_time_ends, w.f_create_time) f_datatime,
                w.f_transaction_id,
                {entity.findDialect()==$SqlServer$: $isnull$,$NVL$}(w.f_userinfo_id,s.f_userinfo_id) f_userinfo_id,
                {entity.findDialect()==$SqlServer$: $isnull$,$NVL$}(w.f_userfiles_id,s.f_userfiles_id) f_userfiles_id,
                {entity.findDialect()==$SqlServer$: $isnull$,$NVL$}(w.f_meter_classify,s.f_meter_type ) f_meter_type,
                {entity.findDialect()==$SqlServer$: $isnull$,$NVL$}(w.f_user_name,s.f_user_name ) f_user_name,
                {entity.findDialect()==$SqlServer$: $isnull$,$NVL$}(w.f_user_type,s.f_user_type ) f_user_type,
                w.f_orgid,
                w.f_meternumber,
                -- w.f_address,
                w.f_userinfo_code,
                s.f_orgname,
                s.f_depid,
                s.f_operatorid,
                s.f_operator,
                s.f_depname,
                s.f_type,
                s.f_serial_id,
                s.f_collection,
                s.f_operate_date
		FROM (
          SELECT
                wx.f_order_type,
                wx.f_transaction_id,
                wx.f_total_fee,
                wx.f_attach,
                wx.id,
                wx.f_order_state,
                wx.f_trade_type,
                wx.f_create_time,
                wx.f_userfiles_id,
                wx.f_orgid,
                CAST(convert(varchar(100),SUBSTRING(f_time_end,1,4) + '-' + SUBSTRING(f_time_end,5,2) + '-' + SUBSTRING(f_time_end,7,2)+ ' '+SUBSTRING(f_time_end,9,2)+ ':'+SUBSTRING(f_time_end,11,2) + ':'+SUBSTRING(f_time_end,13,2),23) as varchar) f_time_ends,
                uf.f_meter_classify,
                uf.f_userinfo_id,
                uf.f_meternumber,
                uf.f_user_type,
                ui.f_userinfo_code,
                ui.f_user_name
                -- address.f_address
          FROM t_weixinreturnxml wx
          LEFT JOIN t_userfiles uf ON wx.f_userfiles_id= uf.f_userfiles_id
          LEFT JOIN t_userinfo ui ON uf.f_userinfo_id = ui.f_userinfo_id
          -- left join t_user_address address on uf.f_userinfo_id = address.f_userinfo_id
          LEFT JOIN t_organization org ON org.id = wx.f_orgid
          WHERE wx.f_order_state = '已支付' and wx.f_transaction_id is not null and wx.f_transaction_id <> ''
		) w
		left join (
		   SELECT
		        s.f_serial_id,
                s.f_userinfo_id,
                s.f_userfiles_id,
                s.f_meter_type,
                s.f_user_name,
                s.f_user_type,
                s.f_orgid,
                s.f_orgname,
                s.f_depid,
                s.f_operatorid,
                s.f_operator,
                s.f_depname,
                s.f_type,
                s.f_collection,
                s.f_operate_date
                -- ui.f_userinfo_code
		   FROM t_sellinggas s
		        -- LEFT JOIN t_userinfo ui ON s.f_userinfo_id = ui.f_userinfo_id
		   WHERE s.f_state in ('有效','冲正')  and s.f_serial_id is not null
            and f_operate_date >= { entity.findDialect() == $SqlServer$: $'{startDate} 00:00:00'$, $to_date('{startDate} 00:00:00','yyyy-mm-dd HH24:mi:ss')}
            and f_operate_date <= { entity.findDialect() == $SqlServer$: $'{endDate} 23:59:59'$, $to_date('{endDate} 23:59:59','yyyy-mm-dd HH24:mi:ss')}
		   union all
-- 		   其他收费
		   SELECT
                s.f_serial_id,
                s.f_userinfo_id,
                s.f_userfiles_id,
                '其他收费' f_meter_type,
                s.f_user_name,
                s.f_user_type,
                s.f_orgid,
                s.f_orgname,
                s.f_depid,
                s.f_operatorid,
                s.f_operator,
                s.f_depname,
                '其他收费' f_type,
                s.f_collection,
                s.f_operate_date
                -- ui.f_userinfo_code
		   FROM t_othercharge s
		        -- LEFT JOIN t_userinfo ui ON s.f_userinfo_id = ui.f_userinfo_id
		   WHERE s.f_state in ('有效','冲正') and s.f_serial_id is not null
            and f_operate_date >= { entity.findDialect() == $SqlServer$: $'{startDate} 00:00:00'$, $to_date('{startDate} 00:00:00','yyyy-mm-dd HH24:mi:ss')}
            and f_operate_date <= { entity.findDialect() == $SqlServer$: $'{endDate} 23:59:59'$, $to_date('{endDate} 23:59:59','yyyy-mm-dd HH24:mi:ss')}
		) s on w.f_transaction_id = s.f_serial_id
)tt
where {condition}
ORDER BY f_datatime DESC

==> sale-3.5.3.jar: revenue/sqls/revenue/BizOperation/WeChatciliation/WeChatPaydetail.sql <==
select  tt.*
from (
		SELECT  (CASE
                     WHEN s.f_serial_id IS NULL AND w.f_transaction_id IS NOT NULL THEN '微信单方面账单'
                     WHEN s.f_serial_id IS NOT NULL AND w.f_transaction_id IS NULL THEN '燃气方单方面账单'
                     else '对账成功'
				END) msg,
		        {entity.findDialect()==$SqlServer$: $isnull$,$NVL$}(( w.f_total_fee + 0.00 ) / ( 100 + 0.00 ),0) f_total_fee,
                w.f_attach,
                w.id,
                w.f_order_state,
                w.f_order_type,
                w.f_trade_type,
                {entity.findDialect()==$SqlServer$: $isnull$,$NVL$}(w.f_time_ends, w.f_create_time) f_datatime,
                w.f_transaction_id,
                {entity.findDialect()==$SqlServer$: $isnull$,$NVL$}(w.f_userinfo_id,s.f_userinfo_id) f_userinfo_id,
                {entity.findDialect()==$SqlServer$: $isnull$,$NVL$}(w.f_userfiles_id,s.f_userfiles_id) f_userfiles_id,
                {entity.findDialect()==$SqlServer$: $isnull$,$NVL$}(w.f_meter_classify,s.f_meter_type ) f_meter_type,
                {entity.findDialect()==$SqlServer$: $isnull$,$NVL$}(w.f_user_name,s.f_user_name ) f_user_name,
                {entity.findDialect()==$SqlServer$: $isnull$,$NVL$}(w.f_user_type,s.f_user_type ) f_user_type,
                w.f_orgid,
                w.f_meternumber,
                -- w.f_address,
                w.f_userinfo_code,
                isnull(s.f_orgname,w.f_orgname) f_orgname,
                isnull(s.f_depid,w.f_depid) f_depid,
                s.f_operatorid,
                s.f_operator,
                s.f_depname,
                s.f_type,
                s.f_serial_id,
                s.f_collection,
                s.f_operate_date
		FROM (
          SELECT
                wx.f_order_type,
                wx.f_transaction_id,
                wx.f_total_fee,
                wx.f_attach,
                wx.id,
                wx.f_order_state,
                wx.f_trade_type,
                wx.f_create_time,
                wx.f_userfiles_id,
                uf.f_orgid,
                uf.f_orgname,
                uf.f_depid,
                CAST(convert(varchar(100),SUBSTRING(f_time_end,1,4) + '-' + SUBSTRING(f_time_end,5,2) + '-' + SUBSTRING(f_time_end,7,2)+ ' '+SUBSTRING(f_time_end,9,2)+ ':'+SUBSTRING(f_time_end,11,2) + ':'+SUBSTRING(f_time_end,13,2),23) as varchar) f_time_ends,
                uf.f_meter_classify,
                uf.f_userinfo_id,
                uf.f_meternumber,
                uf.f_user_type,
                ui.f_userinfo_code,
                ui.f_user_name
                -- address.f_address
          FROM t_weixinreturnxml wx
          LEFT JOIN t_userfiles uf ON wx.f_userfiles_id= uf.f_userfiles_id
          LEFT JOIN t_userinfo ui ON uf.f_userinfo_id = ui.f_userinfo_id
          -- left join t_user_address address on uf.f_userinfo_id = address.f_userinfo_id
          LEFT JOIN t_organization org ON org.id = wx.f_orgid
          WHERE wx.f_order_state = '已支付' and wx.f_transaction_id is not null and wx.f_transaction_id <> ''
		) w
		left join (
		   SELECT
		        s.f_serial_id,
                s.f_userinfo_id,
                s.f_userfiles_id,
                s.f_meter_type,
                s.f_user_name,
                s.f_user_type,
                s.f_orgid,
                s.f_orgname,
                s.f_depid,
                s.f_operatorid,
                s.f_operator,
                s.f_depname,
                s.f_type,
                s.f_collection,
                s.f_operate_date
                -- ui.f_userinfo_code
		   FROM t_sellinggas s
		        -- LEFT JOIN t_userinfo ui ON s.f_userinfo_id = ui.f_userinfo_id
		   WHERE s.f_state in ('有效','冲正')  and s.f_serial_id is not null
            and f_operate_date >= { entity.findDialect() == $SqlServer$: $'{startDate} 00:00:00'$, $to_date('{startDate} 00:00:00','yyyy-mm-dd HH24:mi:ss')}
            and f_operate_date <= { entity.findDialect() == $SqlServer$: $'{endDate} 23:59:59'$, $to_date('{endDate} 23:59:59','yyyy-mm-dd HH24:mi:ss')}
		   union all
-- 		   其他收费
		   SELECT
                s.f_serial_id,
                s.f_userinfo_id,
                s.f_userfiles_id,
                '其他收费' f_meter_type,
                s.f_user_name,
                s.f_user_type,
                s.f_orgid,
                s.f_orgname,
                s.f_depid,
                s.f_operatorid,
                s.f_operator,
                s.f_depname,
                '其他收费' f_type,
                s.f_collection,
                s.f_operate_date
                -- ui.f_userinfo_code
		   FROM t_othercharge s
		        -- LEFT JOIN t_userinfo ui ON s.f_userinfo_id = ui.f_userinfo_id
		   WHERE s.f_state in ('有效','冲正') and s.f_serial_id is not null
            and f_operate_date >= { entity.findDialect() == $SqlServer$: $'{startDate} 00:00:00'$, $to_date('{startDate} 00:00:00','yyyy-mm-dd HH24:mi:ss')}
            and f_operate_date <= { entity.findDialect() == $SqlServer$: $'{endDate} 23:59:59'$, $to_date('{endDate} 23:59:59','yyyy-mm-dd HH24:mi:ss')}
		) s on w.f_transaction_id = s.f_serial_id
)tt
where {condition}
ORDER BY f_datatime DESC
